function [q] = gramschmidt(F)
% Performs Gram-Schmidt orthogonalization of the column
% vectors of F, and puts them in Q.
% The new vectors are NOT normalized.
% Q has as many columns as the rank of F.
[nr nc] = size(F);
if nr == 0, q =[]; break; end
rF=min([nr nc]); %Rank(F) <= rF;
i=1; q=F(1:nr,1);
while (q'*q) < eps & i+1 <= nc
    %Looks for a non-zero column to start with;
    q=F(1:nr,i+1); i=i+1;
end
[nrq ncq]=size(q); normq2=q'*q;
if normq2 < eps, q = []; break; end
while i<=nc & ncq < rF %Stops when enough columns are straight;
    f=F(1:nr,i);
    [nrq ncq]=size(q);
    for j=1:ncq
        qj=q(1:nrq,j);
        f=f-qj*qj'*f/normq2(j); %Gram-Schmidt;
    end
    if f'*f > eps %Then the column was independent, hence
        q = [q f];
        normq2=[normq2; f'*f]; %Saves calculations;
    end
    i=i+1;
end
if q == [0], q = [];
end